@@ -21,8 +21,8 @@
 
 #include "customplugin.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 #include <QtPlugin>
 
-
 Q_EXPORT_PLUGIN2( customplugin, CustomPlugin )
-
+#endif
