@@ -47,7 +47,7 @@ QVariant TypeAccessor<Grantlee::SafeString&>::lookUp( const Grantlee::SafeString
 {
   if ( property == QLatin1String( "capitalize" ) ) {
     const QString s = object.get();
-    return s.at( 0 ).toUpper() + s.right( s.length() - 1 );
+    return QVariant(s.at( 0 ).toUpper() + s.right( s.length() - 1 ));
   }
 
   static const QLatin1String falseString( "False" );
@@ -163,6 +163,8 @@ QVariant TypeAccessor<Grantlee::SafeString&>::lookUp( const Grantlee::SafeString
 
 QVariant doQobjectLookUp( const QObject * const object, const QString &property )
 {
+  if (!object)
+    return QVariant();
   if ( property == QLatin1String( "children" ) ) {
     const QObjectList childList = object->children();
     if ( childList.isEmpty() )
