@@ -300,7 +300,11 @@ void TestBuiltinSyntax::testObjects()
   SafeString s3(s1);
   Q_UNUSED(s3);
 
-  QMetaType::construct(qMetaTypeId<MetaEnumVariable>(), 0);
+  QMetaType::construct(qMetaTypeId<MetaEnumVariable>(), 0
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+                       ,0
+#endif
+                       );
 }
 
 void TestBuiltinSyntax::initTestCase()
@@ -417,6 +421,8 @@ void TestBuiltinSyntax::testBasicSyntax_data()
   QTest::newRow( "basic-syntax15" ) << QString::fromLatin1( "{{ sp%am }}" ) << dict << QString() << TagSyntaxError;
   QTest::newRow( "basic-syntax16" ) << QString::fromLatin1( "{{ eggs! }}" ) << dict << QString() << TagSyntaxError;
   QTest::newRow( "basic-syntax17" ) << QString::fromLatin1( "{{ moo? }}" ) << dict << QString() << TagSyntaxError;
+  QTest::newRow( "basic-syntax-error01" ) << QString::fromLatin1( "{{ moo:arg }}" ) << dict << QString() << TagSyntaxError;
+  QTest::newRow( "basic-syntax-error02" ) << QString::fromLatin1( "{{ moo|cut:'foo':'bar' }}" ) << dict << QString() << TagSyntaxError;
 
   // Attribute syntax allows a template to call a dictionary key's value
 
@@ -1661,4 +1667,3 @@ QTEST_MAIN( TestBuiltinSyntax )
 #include "testbuiltins.moc"
 
 #endif
-
