@@ -42,11 +42,19 @@
 #include <tr1/memory>
 #endif
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 GRANTLEE_REGISTER_SEQUENTIAL_CONTAINER        (ThreeArray)
 GRANTLEE_SEQUENTIAL_TYPE_CONTAINER_ACCESSOR   (ThreeArray)
 
 GRANTLEE_REGISTER_ASSOCIATIVE_CONTAINER       (QtUnorderedMap)
 GRANTLEE_ASSOCIATIVE_TYPE_CONTAINER_ACCESSOR  (QtUnorderedMap)
+#else
+Q_DECLARE_SEQUENTIAL_CONTAINER_METATYPE(ThreeArray)
+
+Q_DECLARE_ASSOCIATIVE_CONTAINER_METATYPE(QtUnorderedMap)
+
+Q_DECLARE_SEQUENTIAL_CONTAINER_METATYPE(std::deque)
+#endif
 
 GRANTLEE_SMART_PTR_ACCESSOR(std::tr1::shared_ptr)
 
